-------------------------------------------------------------------------------
--                                                                           --
-- File         : dirswt.vhd                                                 --
--                                                                           --
-- Author(s)    : Dr. Lars Larsson (LL), www.trinamic.com                    --
--                                                                           --
-- Contributors :                                                            --
--                                                                           --
-- Description  : TMC60x commutator 'dirswt' block (from schematic) cross    --
--                changes high side and low side gate control for DIR='1'    --
--                (direct mapping for DIR='0'.                               --
--                                                                           --
-- Creation     : LL, July 24, 2008                                          --
--                                                                           --
-- History      : LL, February 6, 2010 : BSD license added                   --
--                                                                           --
-------------------------------------------------------------------------------
-- Hint(s)      :                                                            --
-------------------------------------------------------------------------------
--
-- Copyright (c) 2010, TRINAMIC Motion Control GmbH & Co. KG 
-- All rights reserved.
--
-- Redistribution and use in source and binary forms, with or without 
-- modification, are permitted provided that the following conditions 
-- are met:
--
-- Redistributions of source code must retain the above copyright notice, 
-- this list of conditions and the following disclaimer. Redistributions 
-- in binary form must reproduce the above copyright notice, this list of 
-- conditions and the following disclaimer in the documentation and/or 
-- other materials provided with the distribution. 
--
-- Neither the name of the TRINAMIC nor the names of its contributors may 
-- be used to endorse or promote products derived from this software without 
-- specific prior written permission. 
-- 
-- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-- AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-- IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-- ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
-- LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
-- CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
-- SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
-- INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
-- CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
-- ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
-- THE POSSIBILITY OF SUCH DAMAGE.
--
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

entity dirswt is 
  port ( 
  
         DIR    :  in std_logic;
         WT, WB :  in std_logic;
         WH, WL : out std_logic;
         VT, VB :  in std_logic;
         VH, VL : out std_logic;
         UT, UB :  in std_logic;
         UH, UL : out std_logic);
end dirswt;

architecture behavior of dirswt is

begin

   with DIR select WH <= WT when '0', WB when others; 
   with DIR select WL <= WB when '0', WT when others; 
                          
   with DIR select VH <= VT when '0', VB when others; 
   with DIR select VL <= VB when '0', VT when others; 
                          
   with DIR select UH <= UT when '0', UB when others; 
   with DIR select UL <= UB when '0', UT when others; 

end behavior; 

-------------------------------------------------------------------------------
